"""Constante weather data for testings."""

EASYWEATHER_DATA = {
    "PASSKEY": "34271334ED1FADA6D8B988B14267E55D",
    "stationtype": "EasyWeatherV1.4.9",
    "dateutc": "2020-05-04 14:34:26",
    "tempinf": "79.0",
    "humidityin": "33",
    "baromrelin": "28.583",
    "baromabsin": "28.583",
    "tempf": "70.3",
    "humidity": "32",
    "winddir": "200",
    "windspeedmph": "0.4",
    "windgustmph": "1.1",
    "rainratein": "0.000",
    "eventrainin": "0.000",
    "dailyrainin": "0.000",
    "weeklyrainin": "0.079",
    "monthlyrainin": "0.079",
    "yearlyrainin": "0.079",
    "solarradiation": "205.52",
    "uv": "2",
    "freq": "915M",
    "model": "HP3500_V1.6.2",
}

GW2000A_DATA = {
    "PASSKEY": "345544D8EAF42E1B8824A86D8250D5A3",
    "stationtype": "GW2000A_V2.1.5",
    "runtime": "188738",
    "dateutc": "2022-07-15 15:26:14",
    "tempinf": "78.80",
    "humidityin": "53",
    "baromrelin": "27.885",
    "baromabsin": "27.885",
    "tempf": "87.08",
    "humidity": "34",
    "winddir": "289",
    "windspeedmph": "2.91",
    "windgustmph": "3.13",
    "maxdailygust": "12.53",
    "solarradiation": "530.62",
    "uv": "4",
    "rrain_piezo": "0.000",
    "erain_piezo": "0.000",
    "hrain_piezo": "0.000",
    "drain_piezo": "0.000",
    "wrain_piezo": "0.000",
    "mrain_piezo": "0.000",
    "yrain_piezo": "0.000",
    "leak_ch1": "0",
    "leakbatt1": "5",
    "soilad1": "120",
    "leafwetness_ch1": "14",
    "leaf_batt1": "1.78",
    "ws90cap_volt": "5.4",
    "ws90_ver": "119",
    "wh90batt": "2.74",
    "console_batt": "2.5",
    "freq": "868M",
    "model": "GW2000A",
}

GW2000A_V3_DATA = {
    "PASSKEY": "345544D8EAF42E1B8824A86D8250D5A3",
    "stationtype": "GW2000A_V3.1.0",
    "runtime": "158060",
    "heap": "124256",
    "dateutc": "2024-02-08 10: 36: 28",
    "tempinf": "69.44",
    "humidityin": "36",
    "baromrelin": "26.175",
    "baromabsin": "26.175",
    "tempf": "64.76",
    "humidity": "48",
    "winddir": "293",
    "windspeedmph": "0.00",
    "windgustmph": "0.00",
    "maxdailygust": "1.34",
    "solarradiation": "3.87",
    "uv": "0",
    "rrain_piezo": "0.000",
    "erain_piezo": "0.000",
    "hrain_piezo": "0.000",
    "drain_piezo": "0.000",
    "wrain_piezo": "0.000",
    "mrain_piezo": "0.000",
    "yrain_piezo": "0.000",
    "ws90cap_volt": "1.3",
    "ws90_ver": "133",
    "wh90batt": "2.90",
    "freq": "868M",
    "model": "GW2000A",
    "interval": "60",
}
